@@ -26,8 +26,12 @@ class _ExceptionBase(exception.RyuException):
 
 
 class UnexpectedMultiReply(_ExceptionBase):
+    """Two or more replies are received for reply_muiti=False request."""
+
     message = 'Unexpected Multi replies %(result)s'
 
 
 class OFError(_ExceptionBase):
+    """OFPErrorMsg is received."""
+
     message = 'OpenFlow errors %(result)s'
