@@ -1,5 +1,5 @@
 # Copyright (C) 2011 Nippon Telegraph and Telephone Corporation.
-# Copyright (C) 2011 Isaku Yamahata <yamahata at valinux co jp>
+# Copyright (C) 2011, 2012 Isaku Yamahata <yamahata at valinux co jp>
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,8 +16,26 @@
 
 
 NW_ID_EXTERNAL = '__NW_ID_EXTERNAL__'
+NW_ID_RESERVED = '__NW_ID_RESERVED__'
+NW_ID_VPORT_GRE = '__NW_ID_VPORT_GRE__'
 NW_ID_UNKNOWN = '__NW_ID_UNKNOWN__'
 
+RESERVED_NETWORK_IDS = (
+    NW_ID_EXTERNAL,
+    NW_ID_RESERVED,
+    NW_ID_VPORT_GRE,
+    NW_ID_UNKNOWN,
+)
+
+# tunnel type
+_TUNNEL_TYPE_TO_NETWORK_ID = {
+    'gre': NW_ID_VPORT_GRE,
+}
+
+
+def tunnel_type_to_network_id(tunnel_type):
+    return _TUNNEL_TYPE_TO_NETWORK_ID[tunnel_type.lower()]
+
 # PORT_TYPE_VM = 'guestvm'
 # PORT_TYPE_GW = 'gateway'
 # PORT_TYPE_EXTERNAL = 'external'
