@@ -27,9 +27,11 @@ import inspect
 import itertools
 import logging
 import sys
+import os
 
 from ryu import cfg
 from ryu import utils
+from ryu.app import wsgi
 from ryu.controller.handler import register_instance, get_dependent_services
 from ryu.controller.controller import Datapath
 from ryu.controller import event
@@ -65,17 +67,23 @@ def unregister_app(app):
     SERVICE_BRICKS.pop(app.name)
 
 
-def require_app(app_name):
+def require_app(app_name, api_style=False):
     """
-    Request the application to be loaded.
+    Request the application to be automatically loaded.
 
-    This is used for "api" style modules, which is imported by a client
-    application, to automatically load the corresponding server application.
+    If this is used for "api" style modules, which is imported by a client
+    application, set api_style=True.
+
+    If this is used for client application module, set api_style=False.
     """
-    frm = inspect.stack()[2]  # skip a frame for "api" module
+    if api_style:
+        frm = inspect.stack()[2]  # skip a frame for "api" module
+    else:
+        frm = inspect.stack()[1]
     m = inspect.getmodule(frm[0])  # client module
     m._REQUIRED_APP = getattr(m, '_REQUIRED_APP', [])
     m._REQUIRED_APP.append(app_name)
+    LOG.debug('require_app: %s is required by %s', app_name, m.__name__)
 
 
 class RyuApp(object):
@@ -178,8 +186,8 @@ class RyuApp(object):
     def unregister_handler(self, ev_cls, handler):
         assert callable(handler)
         self.event_handlers[ev_cls].remove(handler)
-        if not event_handlers[ev_cls]:
-            del event_handlers[ev_cls]
+        if not self.event_handlers[ev_cls]:
+            del self.event_handlers[ev_cls]
 
     def register_observer(self, ev_cls, name, states=None):
         states = states or set()
@@ -220,9 +228,10 @@ class RyuApp(object):
             return handlers
 
         def test(h):
-            if ev_cls not in h.callers:
-                # this handler does not listen the event.
-                return False
+            if not hasattr(h, 'callers') or ev_cls not in h.callers:
+                # dynamically registered handlers does not have
+                # h.callers element for the event.
+                return True
             states = h.callers[ev_cls].dispatchers
             if not states:
                 # empty states means all states
@@ -317,6 +326,25 @@ class AppManager(object):
     # singletone
     _instance = None
 
+    @staticmethod
+    def run_apps(app_lists):
+        """Run a set of Ryu applications
+
+        A convenient method to load and instantiate apps.
+        This blocks until all relevant apps stop.
+        """
+        app_mgr = AppManager.get_instance()
+        app_mgr.load_apps(app_lists)
+        contexts = app_mgr.create_contexts()
+        services = app_mgr.instantiate_apps(**contexts)
+        webapp = wsgi.start_service(app_mgr)
+        if webapp:
+            services.append(hub.spawn(webapp))
+        try:
+            hub.joinall(services)
+        finally:
+            app_mgr.close()
+
     @staticmethod
     def get_instance():
         if not AppManager._instance:
@@ -331,8 +359,11 @@ class AppManager(object):
 
     def load_app(self, name):
         mod = utils.import_module(name)
-        clses = inspect.getmembers(mod, lambda cls: (inspect.isclass(cls) and
-                                                     issubclass(cls, RyuApp)))
+        clses = inspect.getmembers(mod,
+                                   lambda cls: (inspect.isclass(cls) and
+                                                issubclass(cls, RyuApp) and
+                                                mod.__name__ ==
+                                                cls.__module__))
         if clses:
             return clses[0][1]
         return None
@@ -344,6 +375,11 @@ class AppManager(object):
         while len(app_lists) > 0:
             app_cls_name = app_lists.pop(0)
 
+            context_modules = map(lambda x: x.__module__,
+                                  self.contexts_cls.values())
+            if app_cls_name in context_modules:
+                continue
+
             LOG.info('loading app %s', app_cls_name)
 
             cls = self.load_app(app_cls_name)
@@ -356,19 +392,19 @@ class AppManager(object):
             for key, context_cls in cls.context_iteritems():
                 v = self.contexts_cls.setdefault(key, context_cls)
                 assert v == context_cls
+                context_modules.append(context_cls.__module__)
 
                 if issubclass(context_cls, RyuApp):
                     services.extend(get_dependent_services(context_cls))
 
             # we can't load an app that will be initiataed for
             # contexts.
-            context_modules = map(lambda x: x.__module__,
-                                  self.contexts_cls.values())
             for i in get_dependent_services(cls):
                 if i not in context_modules:
                     services.append(i)
             if services:
-                app_lists.extend(services)
+                app_lists.extend([s for s in set(services)
+                                  if s not in app_lists])
 
     def create_contexts(self):
         for key, cls in self.contexts_cls.items():
