@@ -48,7 +48,8 @@ CONF.register_cli_opts([
     cfg.ListOpt('app-lists', default=[],
                 help='application module name to run'),
     cfg.MultiStrOpt('app', positional=True, default=[],
-                    help='application module name to run')
+                    help='application module name to run'),
+    cfg.StrOpt('pid-file', default=None, help='pid file name'),
 ])
 
 
@@ -63,6 +64,11 @@ def main(args=None, prog=None):
 
     log.init_log()
 
+    if CONF.pid_file:
+        import os
+        with open(CONF.pid_file, 'w') as pid_file:
+            pid_file.write(str(os.getpid()))
+
     app_lists = CONF.app_lists + CONF.app
     # keep old behaivor, run ofp if no application is specified.
     if not app_lists:
