@@ -55,6 +55,24 @@ CONF.register_cli_opts([
     # tests/switch/tester
     cfg.StrOpt('target', default='0000000000000001', help='target sw dp-id'),
     cfg.StrOpt('tester', default='0000000000000002', help='tester sw dp-id'),
+    cfg.IntOpt('target_recv_port', default=1,
+               help='target sw receiving port '
+               '(default: 1)'),
+    cfg.IntOpt('target_send_port_1', default=2,
+               help='target sw sending port 1 '
+               '(default: 2)'),
+    cfg.IntOpt('target_send_port_2', default=3,
+               help='target sw sending port 2  '
+               '(default: 3)'),
+    cfg.IntOpt('tester_send_port', default=1,
+               help='tester sw sending port '
+               '(default: 1)'),
+    cfg.IntOpt('tester_recv_port_1', default=2,
+               help='tester sw receiving port 1 '
+               '(default: 2)'),
+    cfg.IntOpt('tester_recv_port_2', default=3,
+               help='tester sw receiving port 2 '
+               '(default: 3)'),
     cfg.StrOpt('dir', default='ryu/tests/switch/of13',
                help='test files directory'),
     cfg.StrOpt('target-version', default='openflow13',
