@@ -23,8 +23,10 @@ HADDR_PATTERN = r'([0-9a-f]{2}:){5}[0-9a-f]{2}'
 
 DONTCARE = '\x00' * 6
 BROADCAST = '\xff' * 6
-MULTICAST = '\xfe' + '\xff' * 5
-UNICAST = '\x01' + '\x00' * 5
+DONTCARE_STR = '00:00:00:00:00:00'
+BROADCAST_STR = 'ff:ff:ff:ff:ff:ff'
+MULTICAST = 'fe:ff:ff:ff:ff:ff'
+UNICAST = '01:00:00:00:00:00'
 
 
 def is_multicast(addr):
