@@ -54,10 +54,12 @@ DHCP packet format
 """
 import binascii
 import random
-import socket
 import struct
 
 from . import packet_base
+from ryu.lib import addrconv
+from ryu.lib import stringify
+
 
 DHCP_BOOT_REQUEST = 1
 DHCP_BOOT_REPLY = 2
@@ -94,7 +96,9 @@ class dhcp(packet_base.PacketBase):
 
     An instance has the following attributes at least.
     Most of them are same to the on-wire counterparts but in host byte order.
-    __init__ takes the correspondig args in this order.
+    __init__ takes the corresponding args in this order.
+
+    .. tabularcolumns:: |l|L|
 
     ============== ====================
     Attribute      Description
@@ -131,14 +135,21 @@ class dhcp(packet_base.PacketBase):
     """
     _HLEN_UNPACK_STR = '!BBB'
     _HLEN_UNPACK_LEN = struct.calcsize(_HLEN_UNPACK_STR)
-    _DHCP_UNPACK_STR = '!BIHHIIII%ds%ds64s128s'
-    _DHCP_PACK_STR = '!BBBBIHHIIII16s64s128s'
+    _DHCP_UNPACK_STR = '!BIHH4s4s4s4s%ds%ds64s128s'
+    _DHCP_PACK_STR = '!BBBBIHH4s4s4s4s16s64s128s'
     _DHCP_CHADDR_LEN = 16
     _HARDWARE_TYPE_ETHERNET = 1
+    _class_prefixes = ['options']
+    _TYPE = {
+        'ascii': [
+            'ciaddr', 'yiaddr', 'siaddr', 'giaddr', 'chaddr', 'sname'
+        ]
+    }
 
     def __init__(self, op, chaddr, options, htype=_HARDWARE_TYPE_ETHERNET,
-                 hlen=0, hops=0, xid=None, secs=0, flags=0, ciaddr=0, yiaddr=0,
-                 siaddr=0, giaddr=0, sname='', boot_file=''):
+                 hlen=0, hops=0, xid=None, secs=0, flags=0,
+                 ciaddr='0.0.0.0', yiaddr='0.0.0.0', siaddr='0.0.0.0',
+                 giaddr='0.0.0.0', sname='', boot_file=''):
         super(dhcp, self).__init__()
         self.op = op
         self.htype = htype
@@ -176,8 +187,12 @@ class dhcp(packet_base.PacketBase):
         if len(buf) > min_len:
             parse_opt = options.parser(buf[min_len:])
             length += parse_opt.options_len
-        return (cls(op, chaddr, parse_opt, htype, hlen, hops, xid, secs, flags,
-                    ciaddr, yiaddr, siaddr, giaddr, sname, boot_file),
+        return (cls(op, addrconv.mac.bin_to_text(chaddr), parse_opt,
+                    htype, hlen, hops, xid, secs, flags,
+                    addrconv.ipv4.bin_to_text(ciaddr),
+                    addrconv.ipv4.bin_to_text(yiaddr),
+                    addrconv.ipv4.bin_to_text(siaddr),
+                    addrconv.ipv4.bin_to_text(giaddr), sname, boot_file),
                 None, buf[length:])
 
     def serialize(self, payload, prev):
@@ -186,18 +201,24 @@ class dhcp(packet_base.PacketBase):
                               self.options.options_len)
         return struct.pack(pack_str, self.op, self.htype, self.hlen,
                            self.hops, self.xid, self.secs, self.flags,
-                           self.ciaddr, self.yiaddr, self.siaddr, self.giaddr,
-                           self.chaddr, self.sname, self.boot_file, seri_opt)
+                           addrconv.ipv4.text_to_bin(self.ciaddr),
+                           addrconv.ipv4.text_to_bin(self.yiaddr),
+                           addrconv.ipv4.text_to_bin(self.siaddr),
+                           addrconv.ipv4.text_to_bin(self.giaddr),
+                           addrconv.mac.text_to_bin(self.chaddr),
+                           self.sname, self.boot_file, seri_opt)
 
 
-class options(object):
+class options(stringify.StringifyMixin):
     """DHCP (RFC 2132) options encoder/decoder class.
 
     This is used with ryu.lib.packet.dhcp.dhcp.
 
     An instance has the following attributes at least.
     Most of them are same to the on-wire counterparts but in host byte order.
-    __init__ takes the correspondig args in this order.
+    __init__ takes the corresponding args in this order.
+
+    .. tabularcolumns:: |l|L|
 
     ============== ====================
     Attribute      Description
@@ -211,10 +232,16 @@ class options(object):
                    99, 130, 83 and 99.
     ============== ====================
     """
-    _MAGIC_COOKIE_UNPACK_STR = '!I'
+    _MAGIC_COOKIE_UNPACK_STR = '!4s'
     # same magic cookie as is defined in RFC 1497
-    _MAGIC_COOKIE = socket.inet_aton("99.130.83.99")
+    _MAGIC_COOKIE = '99.130.83.99'
     _OPT_TAG_LEN_BYTE = 2
+    _class_prefixes = ['option']
+    _TYPE = {
+        'ascii': [
+            'magic_cookie'
+        ]
+    }
 
     def __init__(self, option_list=None, options_len=0,
                  magic_cookie=_MAGIC_COOKIE):
@@ -238,10 +265,11 @@ class options(object):
                 break
             opt_parse_list.append(opt)
             offset += opt.length + cls._OPT_TAG_LEN_BYTE
-        return cls(opt_parse_list, len(buf), magic_cookie)
+        return cls(opt_parse_list, len(buf),
+                   addrconv.ipv4.bin_to_text(magic_cookie))
 
     def serialize(self):
-        seri_opt = self.magic_cookie
+        seri_opt = addrconv.ipv4.text_to_bin(self.magic_cookie)
         for opt in self.option_list:
             seri_opt += opt.serialize()
         seri_opt += binascii.a2b_hex('%x' % DHCP_END_OPT)
@@ -250,14 +278,14 @@ class options(object):
         return seri_opt
 
 
-class option(object):
+class option(stringify.StringifyMixin):
     """DHCP (RFC 2132) options encoder/decoder class.
 
     This is used with ryu.lib.packet.dhcp.dhcp.options.
 
     An instance has the following attributes at least.
     Most of them are same to the on-wire counterparts but in host byte order.
-    __init__ takes the correspondig args in this order.
+    __init__ takes the corresponding args in this order.
 
     ============== ====================
     Attribute      Description
