@@ -695,6 +695,18 @@ class MFTPSRC(MFField):
         return self.putm(buf, offset, rule.flow.tp_src, rule.wc.tp_src_mask)
 
 
+@_register_make
+@_set_nxm_headers([ofproto_v1_0.NXM_OF_TCP_DST, ofproto_v1_0.NXM_OF_TCP_DST_W,
+                   ofproto_v1_0.NXM_OF_UDP_DST, ofproto_v1_0.NXM_OF_UDP_DST_W])
+class MFTPDST(MFField):
+    @classmethod
+    def make(cls, header):
+        return cls(header, MF_PACK_STRING_BE16)
+
+    def put(self, buf, offset, rule):
+        return self.putm(buf, offset, rule.flow.tp_dst, rule.wc.tp_dst_mask)
+
+
 @_register_make
 @_set_nxm_headers([ofproto_v1_0.NXM_OF_ARP_SPA, ofproto_v1_0.NXM_OF_ARP_SPA_W])
 class MFArpSpa(MFField):
