@@ -526,6 +526,75 @@ class BGPSpeaker(object):
         param['port'] = port
         call(func_name, **param)
 
+    def attribute_map_set(self, address, attribute_maps,
+                          route_dist=None, route_family=RF_VPN_V4):
+        """This method sets attribute mapping to a neighbor.
+        attribute mapping can be used when you want to apply
+        attribute to BGPUpdate under specific conditions.
+
+        ``address`` specifies the IP address of the neighbor
+
+        ``attribute_maps`` specifies attribute_map list that are used
+        before paths are advertised. All the items in the list must
+        be an instance of AttributeMap class
+
+        ``route_dist`` specifies route dist in which attribute_maps
+        are added.
+
+        ``route_family`` specifies route family of the VRF.
+        This parameter must be RF_VPN_V4 or RF_VPN_V6.
+
+        We can set AttributeMap to a neighbor as follows;
+
+          pref_filter = PrefixFilter('192.168.103.0/30',
+                                     PrefixFilter.POLICY_PERMIT)
+
+          attribute_map = AttributeMap([pref_filter],
+                                       AttributeMap.ATTR_LOCAL_PREF, 250)
+
+          speaker.attribute_map_set('192.168.50.102', [attribute_map])
+
+        """
+
+        assert route_family in (RF_VPN_V4, RF_VPN_V6),\
+            'route_family must be RF_VPN_V4 or RF_VPN_V6'
+
+        func_name = 'neighbor.attribute_map.set'
+        param = {}
+        param[neighbors.IP_ADDRESS] = address
+        param[neighbors.ATTRIBUTE_MAP] = attribute_maps
+        if route_dist is not None:
+            param[vrfs.ROUTE_DISTINGUISHER] = route_dist
+            param[vrfs.VRF_RF] = route_family
+        call(func_name, **param)
+
+    def attribute_map_get(self, address, route_dist=None,
+                          route_family=RF_VPN_V4):
+        """This method gets in-bound filters of the specified neighbor.
+
+        ``address`` specifies the IP address of the neighbor.
+
+        ``route_dist`` specifies route distinguisher that has attribute_maps.
+
+        ``route_family`` specifies route family of the VRF.
+        This parameter must be RF_VPN_V4 or RF_VPN_V6.
+
+        Returns a list object containing an instance of AttributeMap
+
+        """
+
+        assert route_family in (RF_VPN_V4, RF_VPN_V6),\
+            'route_family must be RF_VPN_V4 or RF_VPN_V6'
+
+        func_name = 'neighbor.attribute_map.get'
+        param = {}
+        param[neighbors.IP_ADDRESS] = address
+        if route_dist is not None:
+            param[vrfs.ROUTE_DISTINGUISHER] = route_dist
+            param[vrfs.VRF_RF] = route_family
+        attribute_maps = call(func_name, **param)
+        return attribute_maps
+
     @staticmethod
     def _check_rf_and_normalize(prefix):
         """ check prefix's route_family and if the address is
