@@ -30,12 +30,16 @@ from ryu.services.protocols.bgp import constants as const
 from ryu.services.protocols.bgp.model import OutgoingRoute
 from ryu.services.protocols.bgp.model import SentRoute
 from ryu.services.protocols.bgp.info_base.base import PrefixFilter
+from ryu.services.protocols.bgp.info_base.base import AttributeMap
 from ryu.services.protocols.bgp.model import ReceivedRoute
 from ryu.services.protocols.bgp.net_ctrl import NET_CONTROLLER
 from ryu.services.protocols.bgp.rtconf.neighbors import NeighborConfListener
 from ryu.services.protocols.bgp.signals.emit import BgpSignalBus
 from ryu.services.protocols.bgp.speaker import BgpProtocol
 from ryu.services.protocols.bgp.info_base.ipv4 import Ipv4Path
+from ryu.services.protocols.bgp.info_base.vpnv4 import Vpnv4Path
+from ryu.services.protocols.bgp.info_base.vpnv6 import Vpnv6Path
+from ryu.services.protocols.bgp.rtconf.vrfs import VRF_RF_IPV4, VRF_RF_IPV6
 from ryu.services.protocols.bgp.utils import bgp as bgp_utils
 from ryu.services.protocols.bgp.utils.evtlet import EventletIOFactory
 from ryu.services.protocols.bgp.utils import stats
@@ -349,6 +353,9 @@ class Peer(Source, Sink, NeighborConfListener, Activity):
         # Adj-rib-out
         self._adj_rib_out = {}
 
+        # attribute maps
+        self._attribute_maps = {}
+
     @property
     def remote_as(self):
         return self._neigh_conf.remote_as
@@ -409,6 +416,32 @@ class Peer(Source, Sink, NeighborConfListener, Activity):
     def check_first_as(self):
         return self._neigh_conf.check_first_as
 
+    @property
+    def attribute_maps(self):
+        return self._attribute_maps
+
+    @attribute_maps.setter
+    def attribute_maps(self, attribute_maps):
+        _attr_maps = {}
+        _attr_maps.setdefault(const.ATTR_MAPS_ORG_KEY, [])
+
+        # key is 'default' or rd_rf that represents RD and route_family
+        key = attribute_maps[const.ATTR_MAPS_LABEL_KEY]
+        at_maps = attribute_maps[const.ATTR_MAPS_VALUE]
+
+        for a in at_maps:
+            cloned = a.clone()
+            LOG.debug("AttributeMap attr_type: %s, attr_value: %s",
+                      cloned.attr_type, cloned.attr_value)
+            attr_list = _attr_maps.setdefault(cloned.attr_type, [])
+            attr_list.append(cloned)
+
+            # preserve original order of attribute_maps
+            _attr_maps[const.ATTR_MAPS_ORG_KEY].append(cloned)
+
+        self._attribute_maps[key] = _attr_maps
+        self.on_update_attribute_maps()
+
     def is_mpbgp_cap_valid(self, route_family):
         if not self.in_established:
             raise ValueError('Invalid request: Peer not in established state')
@@ -568,6 +601,14 @@ class Peer(Source, Sink, NeighborConfListener, Activity):
             sent_path.filtered = block
             self.enque_outgoing_msg(outgoing_route)
 
+    def on_update_attribute_maps(self):
+        # resend sent_route in case of filter matching
+        LOG.debug('on_update_attribute_maps fired')
+        for sent_path in self._adj_rib_out.itervalues():
+            LOG.debug('resend path: %s' % sent_path)
+            path = sent_path.path
+            self.enque_outgoing_msg(OutgoingRoute(path))
+
     def __str__(self):
         return 'Peer(ip: %s, asn: %s)' % (self._neigh_conf.ip_address,
                                           self._neigh_conf.remote_as)
@@ -869,8 +910,23 @@ class Peer(Source, Sink, NeighborConfListener, Activity):
             # LOCAL_PREF Attribute.
             if not self.is_ebgp_peer():
                 # For iBGP peers we are required to send local-pref attribute
-                # for connected or local prefixes. We send default local-pref.
+                # for connected or local prefixes. We check if the path matches
+                # attribute_maps and set local-pref value.
+                # If the path doesn't match, we set default local-pref 100.
                 localpref_attr = BGPPathAttributeLocalPref(100)
+                key = const.ATTR_MAPS_LABEL_DEFAULT
+
+                if isinstance(path, (Vpnv4Path, Vpnv6Path)):
+                    nlri = nlri_list[0]
+                    rf = VRF_RF_IPV4 if isinstance(path, Vpnv4Path)\
+                        else VRF_RF_IPV6
+                    key = ':'.join([nlri.route_dist, rf])
+
+                attr_type = AttributeMap.ATTR_LOCAL_PREF
+                at_maps = self._attribute_maps.get(key, {})
+                result = self._lookup_attribute_map(at_maps, attr_type, path)
+                if result:
+                    localpref_attr = result
 
             # COMMUNITY Attribute.
             community_attr = pathattr_map.get(BGP_ATTR_TYPE_COMMUNITIES)
@@ -1921,3 +1977,18 @@ class Peer(Source, Sink, NeighborConfListener, Activity):
             if self._neigh_conf.enabled:
                 if not self._connect_retry_event.is_set():
                     self._connect_retry_event.set()
+
+    @staticmethod
+    def _lookup_attribute_map(attribute_map, attr_type, path):
+        result_attr = None
+        if attr_type in attribute_map:
+            maps = attribute_map[attr_type]
+            for m in maps:
+                cause, result = m.evaluate(path)
+                LOG.debug(
+                    "local_pref evaluation result:%s, cause:%s",
+                    result, cause)
+                if result:
+                    result_attr = m.get_attribute()
+                    break
+        return result_attr
