@@ -9,6 +9,7 @@ import logging
 from nose import result
 from nose import core
 from nose import config
+from nose.plugins.skip import SkipTest
 
 
 class _AnsiColorizer(object):
@@ -65,9 +66,9 @@ class _Win32Colorizer(object):
     See _AnsiColorizer docstring.
     """
     def __init__(self, stream):
-        from win32console import GetStdHandle, STD_OUT_HANDLE, \
-             FOREGROUND_RED, FOREGROUND_BLUE, FOREGROUND_GREEN, \
-             FOREGROUND_INTENSITY
+        from win32console import GetStdHandle, STD_OUT_HANDLE
+        from win32console import FOREGROUND_RED, FOREGROUND_BLUE
+        from win32console import FOREGROUND_GREEN, FOREGROUND_INTENSITY
         red, green, blue, bold = (FOREGROUND_RED, FOREGROUND_GREEN,
                                   FOREGROUND_BLUE, FOREGROUND_INTENSITY)
         self.stream = stream
@@ -206,9 +207,9 @@ class RyuTestResult(result.TextTestResult):
             if current_case != self._last_case:
                 self.stream.writeln(current_case)
                 self._last_case = current_case
-            #NOTE(salvatore-orlando):
-            #slightly changed in order to print test case class
-            #together with unit test name
+            # NOTE(salvatore-orlando):
+            # slightly changed in order to print test case class
+            # together with unit test name
             self.stream.write(
                 '    %s' % str(test.test).ljust(60))
             self.stream.flush()
@@ -217,9 +218,9 @@ class RyuTestResult(result.TextTestResult):
 class RyuTestRunner(core.TextTestRunner):
     def _makeResult(self):
         return RyuTestResult(self.stream,
-                              self.descriptions,
-                              self.verbosity,
-                              self.config)
+                             self.descriptions,
+                             self.verbosity,
+                             self.config)
 
 
 def run_tests(c=None):
@@ -239,6 +240,6 @@ def run_tests(c=None):
         return True
 
     runner = RyuTestRunner(stream=c.stream,
-                            verbosity=c.verbosity,
-                            config=c)
+                           verbosity=c.verbosity,
+                           config=c)
     return not core.run(config=c, testRunner=runner)
