@@ -112,6 +112,10 @@ implemented = {
         ofproto_v1_4.OFPT_GET_ASYNC_REPLY: (True, False),
         ofproto_v1_4.OFPT_SET_ASYNC: (False, True),
         ofproto_v1_4.OFPT_ROLE_STATUS: (True, False),
+        ofproto_v1_4.OFPT_TABLE_STATUS: (True, False),
+        ofproto_v1_4.OFPT_REQUESTFORWARD: (False, True),
+        ofproto_v1_4.OFPT_BUNDLE_CONTROL: (False, True),
+        ofproto_v1_4.OFPT_BUNDLE_ADD_MESSAGE: (False, True),
     },
 }
 
