@@ -300,10 +300,10 @@ class Test_lacp(unittest.TestCase):
                 return p
 
     def test_init(self):
-        eq_(self.subtype, self.l.subtype)
+        eq_(self.subtype, self.l._subtype)
         eq_(self.version, self.l.version)
-        eq_(self.actor_tag, self.l.actor_tag)
-        eq_(self.actor_length, self.l.actor_length)
+        eq_(self.actor_tag, self.l._actor_tag)
+        eq_(self.actor_length, self.l._actor_length)
         eq_(self.actor_system_priority, self.l.actor_system_priority)
         eq_(self.actor_system, self.l.actor_system)
         eq_(self.actor_key, self.l.actor_key)
@@ -321,9 +321,9 @@ class Test_lacp(unittest.TestCase):
             self.l.actor_state_distributing)
         eq_(self.actor_state_defaulted, self.l.actor_state_defaulted)
         eq_(self.actor_state_expired, self.l.actor_state_expired)
-        eq_(self.actor_state, self.l.actor_state)
-        eq_(self.partner_tag, self.l.partner_tag)
-        eq_(self.partner_length, self.l.partner_length)
+        eq_(self.actor_state, self.l._actor_state)
+        eq_(self.partner_tag, self.l._partner_tag)
+        eq_(self.partner_length, self.l._partner_length)
         eq_(self.partner_system_priority,
             self.l.partner_system_priority)
         eq_(self.partner_system, self.l.partner_system)
@@ -343,12 +343,12 @@ class Test_lacp(unittest.TestCase):
         eq_(self.partner_state_defaulted,
             self.l.partner_state_defaulted)
         eq_(self.partner_state_expired, self.l.partner_state_expired)
-        eq_(self.partner_state, self.l.partner_state)
-        eq_(self.collector_tag, self.l.collector_tag)
-        eq_(self.collector_length, self.l.collector_length)
+        eq_(self.partner_state, self.l._partner_state)
+        eq_(self.collector_tag, self.l._collector_tag)
+        eq_(self.collector_length, self.l._collector_length)
         eq_(self.collector_max_delay, self.l.collector_max_delay)
-        eq_(self.terminator_tag, self.l.terminator_tag)
-        eq_(self.terminator_length, self.l.terminator_length)
+        eq_(self.terminator_tag, self.l._terminator_tag)
+        eq_(self.terminator_length, self.l._terminator_length)
 
     def test_parser(self):
         _res = self.l.parser(self.buf)
@@ -357,10 +357,10 @@ class Test_lacp(unittest.TestCase):
         else:
             res = _res
 
-        eq_(res.subtype, self.subtype)
+        eq_(res._subtype, self.subtype)
         eq_(res.version, self.version)
-        eq_(res.actor_tag, self.actor_tag)
-        eq_(res.actor_length, self.actor_length)
+        eq_(res._actor_tag, self.actor_tag)
+        eq_(res._actor_length, self.actor_length)
         eq_(res.actor_system_priority, self.actor_system_priority)
         eq_(res.actor_system, self.actor_system)
         eq_(res.actor_key, self.actor_key)
@@ -375,9 +375,9 @@ class Test_lacp(unittest.TestCase):
         eq_(res.actor_state_distributing, self.actor_state_distributing)
         eq_(res.actor_state_defaulted, self.actor_state_defaulted)
         eq_(res.actor_state_expired, self.actor_state_expired)
-        eq_(res.actor_state, self.actor_state)
-        eq_(res.partner_tag, self.partner_tag)
-        eq_(res.partner_length, self.partner_length)
+        eq_(res._actor_state, self.actor_state)
+        eq_(res._partner_tag, self.partner_tag)
+        eq_(res._partner_length, self.partner_length)
         eq_(res.partner_system_priority, self.partner_system_priority)
         eq_(res.partner_system, self.partner_system)
         eq_(res.partner_key, self.partner_key)
@@ -394,12 +394,12 @@ class Test_lacp(unittest.TestCase):
             self.partner_state_distributing)
         eq_(res.partner_state_defaulted, self.partner_state_defaulted)
         eq_(res.partner_state_expired, self.partner_state_expired)
-        eq_(res.partner_state, self.partner_state)
-        eq_(res.collector_tag, self.collector_tag)
-        eq_(res.collector_length, self.collector_length)
+        eq_(res._partner_state, self.partner_state)
+        eq_(res._collector_tag, self.collector_tag)
+        eq_(res._collector_length, self.collector_length)
         eq_(res.collector_max_delay, self.collector_max_delay)
-        eq_(res.terminator_tag, self.terminator_tag)
-        eq_(res.terminator_length, self.terminator_length)
+        eq_(res._terminator_tag, self.terminator_tag)
+        eq_(res._terminator_length, self.terminator_length)
 
     def test_serialize(self):
         data = bytearray()
@@ -466,10 +466,10 @@ class Test_lacp(unittest.TestCase):
         l = self.find_protocol(p, "lacp")
         ok_(l)
 
-        eq_(l.subtype, self.subtype)
+        eq_(l._subtype, self.subtype)
         eq_(l.version, self.version)
-        eq_(l.actor_tag, self.actor_tag)
-        eq_(l.actor_length, self.actor_length)
+        eq_(l._actor_tag, self.actor_tag)
+        eq_(l._actor_length, self.actor_length)
         eq_(l.actor_system_priority, self.actor_system_priority)
         eq_(l.actor_system, self.actor_system)
         eq_(l.actor_key, self.actor_key)
@@ -484,9 +484,9 @@ class Test_lacp(unittest.TestCase):
         eq_(l.actor_state_distributing, self.actor_state_distributing)
         eq_(l.actor_state_defaulted, self.actor_state_defaulted)
         eq_(l.actor_state_expired, self.actor_state_expired)
-        eq_(l.actor_state, self.actor_state)
-        eq_(l.partner_tag, self.partner_tag)
-        eq_(l.partner_length, self.partner_length)
+        eq_(l._actor_state, self.actor_state)
+        eq_(l._partner_tag, self.partner_tag)
+        eq_(l._partner_length, self.partner_length)
         eq_(l.partner_system_priority, self.partner_system_priority)
         eq_(l.partner_system, self.partner_system)
         eq_(l.partner_key, self.partner_key)
@@ -502,11 +502,12 @@ class Test_lacp(unittest.TestCase):
             self.partner_state_distributing)
         eq_(l.partner_state_defaulted, self.partner_state_defaulted)
         eq_(l.partner_state_expired, self.partner_state_expired)
-        eq_(l.collector_tag, self.collector_tag)
-        eq_(l.collector_length, self.collector_length)
+        eq_(l._partner_state, self.partner_state)
+        eq_(l._collector_tag, self.collector_tag)
+        eq_(l._collector_length, self.collector_length)
         eq_(l.collector_max_delay, self.collector_max_delay)
-        eq_(l.terminator_tag, self.terminator_tag)
-        eq_(l.terminator_length, self.terminator_length)
+        eq_(l._terminator_tag, self.terminator_tag)
+        eq_(l._terminator_length, self.terminator_length)
 
     @raises(Exception)
     def test_malformed_lacp(self):
@@ -1094,3 +1095,8 @@ class Test_lacp(unittest.TestCase):
                  -1,
                  self.collector_max_delay)
         l.serialize()
+
+    def test_json(self):
+        jsondict = self.l.to_jsondict()
+        l = lacp.from_jsondict(jsondict['lacp'])
+        eq_(str(self.l), str(l))
