@@ -145,8 +145,8 @@ class Test_tcp(unittest.TestCase):
         buf = t.serialize(bytearray(), prev)
         res = struct.unpack(tcp._PACK_STR, buf)
 
-        eq_(res[0], 0)
-        eq_(res[1], 0)
+        eq_(res[0], 1)
+        eq_(res[1], 1)
         eq_(res[2], 0)
         eq_(res[3], 0)
         eq_(res[4], 5 << 4)
@@ -159,8 +159,8 @@ class Test_tcp(unittest.TestCase):
         buf = t.serialize(bytearray(), prev)
         res = struct.unpack(tcp._PACK_STR + '4s', buf)
 
-        eq_(res[0], 0)
-        eq_(res[1], 0)
+        eq_(res[0], 1)
+        eq_(res[1], 1)
         eq_(res[2], 0)
         eq_(res[3], 0)
         eq_(res[4], 6 << 4)
@@ -174,8 +174,8 @@ class Test_tcp(unittest.TestCase):
         buf = t.serialize(bytearray(), prev)
         res = struct.unpack(tcp._PACK_STR + '8s', buf)
 
-        eq_(res[0], 0)
-        eq_(res[1], 0)
+        eq_(res[0], 1)
+        eq_(res[1], 1)
         eq_(res[2], 0)
         eq_(res[3], 0)
         eq_(res[4], 7 << 4)
@@ -183,3 +183,8 @@ class Test_tcp(unittest.TestCase):
         eq_(res[6], 0)
         eq_(res[8], 0)
         eq_(res[9], '\x01\x02\x03\x00\x00\x00\x00\x00')
+
+    def test_json(self):
+        jsondict = self.t.to_jsondict()
+        t = tcp.from_jsondict(jsondict['tcp'])
+        eq_(str(self.t), str(t))
