@@ -101,6 +101,11 @@ class Test_udp(unittest.TestCase):
         buf = u.serialize(bytearray(), prev)
         res = struct.unpack(udp._PACK_STR, buf)
 
-        eq_(res[0], 0)
-        eq_(res[1], 0)
+        eq_(res[0], 1)
+        eq_(res[1], 1)
         eq_(res[2], udp._MIN_LEN)
+
+    def test_json(self):
+        jsondict = self.u.to_jsondict()
+        u = udp.from_jsondict(jsondict['udp'])
+        eq_(str(self.u), str(u))
